# [LitProg][repo_ref]

Project/Repo:

[![MIT License][license_img]][license_ref]
[![Supported Python Versions][pyversions_img]][pyversions_ref]
[![CalVer 2021.1005-alpha][version_img]][version_ref]
[![PyPI Version][pypi_img]][pypi_ref]
[![PyPI Downloads][downloads_img]][downloads_ref]

Code Quality/CI:

[![Type Checked with mypy][mypy_img]][mypy_ref]
[![Code Style: sjfmt][style_img]][style_ref]
[![Code Coverage][codecov_img]][codecov_ref]
[![GitHub CI Status][github_build_img]][github_build_ref]
[![GitLab CI Status][gitlab_build_img]][gitlab_build_ref]


|               Name                  |    role           |  since  | until |
|-------------------------------------|-------------------|---------|-------|
| Manuel Barkhau (mbarkhau@gmail.com) | author/maintainer | 2018-12 | -     |


<!--
  To update the TOC:
  $ pip install md-toc
  $ md_toc -i gitlab README.md
-->


[](TOC)

[](TOC)


[repo_ref]: https://github.com/litprog/litprog

[github_build_img]: https://github.com/litprog/litprog/workflows/CI/badge.svg
[github_build_ref]: https://github.com/litprog/litprog/actions?query=workflow%3ACI

[gitlab_build_img]: https://gitlab.com/mbarkhau/litprog/badges/master/pipeline.svg
[gitlab_build_ref]: https://gitlab.com/mbarkhau/litprog/pipelines

[codecov_img]: https://gitlab.com/mbarkhau/litprog/badges/master/coverage.svg
[codecov_ref]: https://mbarkhau.gitlab.io/litprog/cov

[license_img]: https://img.shields.io/badge/License-MIT-blue.svg
[license_ref]: https://gitlab.com/mbarkhau/litprog/blob/master/LICENSE

[mypy_img]: https://img.shields.io/badge/mypy-checked-green.svg
[mypy_ref]: http://mypy-lang.org/

[style_img]: https://img.shields.io/badge/code%20style-%20sjfmt-f71.svg
[style_ref]: https://gitlab.com/mbarkhau/straitjacket/

[pypi_img]: https://img.shields.io/badge/PyPI-wheels-green.svg
[pypi_ref]: https://pypi.org/project/litprog/#files

[downloads_img]: https://pepy.tech/badge/litprog/month
[downloads_ref]: https://pepy.tech/project/litprog

[version_img]: https://img.shields.io/badge/CalVer-2021.1005--alpha-blue.svg
[version_ref]: https://pypi.org/project/pycalver/

[pyversions_img]: https://img.shields.io/pypi/pyversions/litprog.svg
[pyversions_ref]: https://pypi.python.org/pypi/litprog

